@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import IO, Any, Dict, List, Type, Union, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 from botocore.response import StreamingBody
 
 from .literals import EnhancedMonitoringType
@@ -29,41 +29,41 @@ from .paginator import (
     ListScramSecretsPaginator,
 )
 from .type_defs import (
-    BatchAssociateScramSecretResponseResponseTypeDef,
-    BatchDisassociateScramSecretResponseResponseTypeDef,
+    BatchAssociateScramSecretResponseTypeDef,
+    BatchDisassociateScramSecretResponseTypeDef,
     BrokerEBSVolumeInfoTypeDef,
     BrokerNodeGroupInfoTypeDef,
     ClientAuthenticationTypeDef,
     ConfigurationInfoTypeDef,
-    CreateClusterResponseResponseTypeDef,
-    CreateConfigurationResponseResponseTypeDef,
-    DeleteClusterResponseResponseTypeDef,
-    DeleteConfigurationResponseResponseTypeDef,
-    DescribeClusterOperationResponseResponseTypeDef,
-    DescribeClusterResponseResponseTypeDef,
-    DescribeConfigurationResponseResponseTypeDef,
-    DescribeConfigurationRevisionResponseResponseTypeDef,
+    CreateClusterResponseTypeDef,
+    CreateConfigurationResponseTypeDef,
+    DeleteClusterResponseTypeDef,
+    DeleteConfigurationResponseTypeDef,
+    DescribeClusterOperationResponseTypeDef,
+    DescribeClusterResponseTypeDef,
+    DescribeConfigurationResponseTypeDef,
+    DescribeConfigurationRevisionResponseTypeDef,
     EncryptionInfoTypeDef,
-    GetBootstrapBrokersResponseResponseTypeDef,
-    GetCompatibleKafkaVersionsResponseResponseTypeDef,
-    ListClusterOperationsResponseResponseTypeDef,
-    ListClustersResponseResponseTypeDef,
-    ListConfigurationRevisionsResponseResponseTypeDef,
-    ListConfigurationsResponseResponseTypeDef,
-    ListKafkaVersionsResponseResponseTypeDef,
-    ListNodesResponseResponseTypeDef,
-    ListScramSecretsResponseResponseTypeDef,
-    ListTagsForResourceResponseResponseTypeDef,
+    GetBootstrapBrokersResponseTypeDef,
+    GetCompatibleKafkaVersionsResponseTypeDef,
+    ListClusterOperationsResponseTypeDef,
+    ListClustersResponseTypeDef,
+    ListConfigurationRevisionsResponseTypeDef,
+    ListConfigurationsResponseTypeDef,
+    ListKafkaVersionsResponseTypeDef,
+    ListNodesResponseTypeDef,
+    ListScramSecretsResponseTypeDef,
+    ListTagsForResourceResponseTypeDef,
     LoggingInfoTypeDef,
     OpenMonitoringInfoTypeDef,
-    RebootBrokerResponseResponseTypeDef,
-    UpdateBrokerCountResponseResponseTypeDef,
-    UpdateBrokerStorageResponseResponseTypeDef,
-    UpdateBrokerTypeResponseResponseTypeDef,
-    UpdateClusterConfigurationResponseResponseTypeDef,
-    UpdateClusterKafkaVersionResponseResponseTypeDef,
-    UpdateConfigurationResponseResponseTypeDef,
-    UpdateMonitoringResponseResponseTypeDef,
+    RebootBrokerResponseTypeDef,
+    UpdateBrokerCountResponseTypeDef,
+    UpdateBrokerStorageResponseTypeDef,
+    UpdateBrokerTypeResponseTypeDef,
+    UpdateClusterConfigurationResponseTypeDef,
+    UpdateClusterKafkaVersionResponseTypeDef,
+    UpdateConfigurationResponseTypeDef,
+    UpdateMonitoringResponseTypeDef,
 )
 
 if sys.version_info >= (3, 8):
@@ -95,32 +95,37 @@ class Exceptions:
     UnauthorizedException: Type[BotocoreClientError]
 
 
-class KafkaClient:
+class KafkaClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        KafkaClient exceptions.
+        """
 
     def batch_associate_scram_secret(
         self, *, ClusterArn: str, SecretArnList: List[str]
-    ) -> BatchAssociateScramSecretResponseResponseTypeDef:
+    ) -> BatchAssociateScramSecretResponseTypeDef:
         """
         Associates one or more Scram Secrets with an Amazon MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.batch_associate_scram_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.batch_associate_scram_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#batch_associate_scram_secret)
         """
 
     def batch_disassociate_scram_secret(
         self, *, ClusterArn: str, SecretArnList: List[str]
-    ) -> BatchDisassociateScramSecretResponseResponseTypeDef:
+    ) -> BatchDisassociateScramSecretResponseTypeDef:
         """
         Disassociates one or more Scram Secrets from an Amazon MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.batch_disassociate_scram_secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.batch_disassociate_scram_secret)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#batch_disassociate_scram_secret)
         """
 
@@ -128,7 +133,7 @@ class KafkaClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#can_paginate)
         """
 
@@ -146,11 +151,11 @@ class KafkaClient:
         OpenMonitoring: "OpenMonitoringInfoTypeDef" = None,
         LoggingInfo: "LoggingInfoTypeDef" = None,
         Tags: Dict[str, str] = None
-    ) -> CreateClusterResponseResponseTypeDef:
+    ) -> CreateClusterResponseTypeDef:
         """
         Creates a new MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.create_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.create_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#create_cluster)
         """
 
@@ -161,67 +166,67 @@ class KafkaClient:
         ServerProperties: Union[bytes, IO[bytes], StreamingBody],
         Description: str = None,
         KafkaVersions: List[str] = None
-    ) -> CreateConfigurationResponseResponseTypeDef:
+    ) -> CreateConfigurationResponseTypeDef:
         """
         Creates a new MSK configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.create_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.create_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#create_configuration)
         """
 
     def delete_cluster(
         self, *, ClusterArn: str, CurrentVersion: str = None
-    ) -> DeleteClusterResponseResponseTypeDef:
+    ) -> DeleteClusterResponseTypeDef:
         """
         Deletes the MSK cluster specified by the Amazon Resource Name (ARN) in the
         request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.delete_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.delete_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#delete_cluster)
         """
 
-    def delete_configuration(self, *, Arn: str) -> DeleteConfigurationResponseResponseTypeDef:
+    def delete_configuration(self, *, Arn: str) -> DeleteConfigurationResponseTypeDef:
         """
         Deletes an MSK Configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.delete_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.delete_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#delete_configuration)
         """
 
-    def describe_cluster(self, *, ClusterArn: str) -> DescribeClusterResponseResponseTypeDef:
+    def describe_cluster(self, *, ClusterArn: str) -> DescribeClusterResponseTypeDef:
         """
         Returns a description of the MSK cluster whose Amazon Resource Name (ARN) is
         specified in the request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.describe_cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.describe_cluster)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_cluster)
         """
 
     def describe_cluster_operation(
         self, *, ClusterOperationArn: str
-    ) -> DescribeClusterOperationResponseResponseTypeDef:
+    ) -> DescribeClusterOperationResponseTypeDef:
         """
         Returns a description of the cluster operation specified by the ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.describe_cluster_operation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.describe_cluster_operation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_cluster_operation)
         """
 
-    def describe_configuration(self, *, Arn: str) -> DescribeConfigurationResponseResponseTypeDef:
+    def describe_configuration(self, *, Arn: str) -> DescribeConfigurationResponseTypeDef:
         """
         Returns a description of this MSK configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.describe_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.describe_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_configuration)
         """
 
     def describe_configuration_revision(
         self, *, Arn: str, Revision: int
-    ) -> DescribeConfigurationRevisionResponseResponseTypeDef:
+    ) -> DescribeConfigurationRevisionResponseTypeDef:
         """
         Returns a description of this revision of the configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.describe_configuration_revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.describe_configuration_revision)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#describe_configuration_revision)
         """
 
@@ -235,118 +240,114 @@ class KafkaClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#generate_presigned_url)
         """
 
-    def get_bootstrap_brokers(
-        self, *, ClusterArn: str
-    ) -> GetBootstrapBrokersResponseResponseTypeDef:
+    def get_bootstrap_brokers(self, *, ClusterArn: str) -> GetBootstrapBrokersResponseTypeDef:
         """
         A list of brokers that a client application can use to bootstrap.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.get_bootstrap_brokers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.get_bootstrap_brokers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#get_bootstrap_brokers)
         """
 
     def get_compatible_kafka_versions(
         self, *, ClusterArn: str = None
-    ) -> GetCompatibleKafkaVersionsResponseResponseTypeDef:
+    ) -> GetCompatibleKafkaVersionsResponseTypeDef:
         """
         Gets the Apache Kafka versions to which you can update the MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.get_compatible_kafka_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.get_compatible_kafka_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#get_compatible_kafka_versions)
         """
 
     def list_cluster_operations(
         self, *, ClusterArn: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListClusterOperationsResponseResponseTypeDef:
+    ) -> ListClusterOperationsResponseTypeDef:
         """
         Returns a list of all the operations that have been performed on the specified
         MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.list_cluster_operations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.list_cluster_operations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_cluster_operations)
         """
 
     def list_clusters(
         self, *, ClusterNameFilter: str = None, MaxResults: int = None, NextToken: str = None
-    ) -> ListClustersResponseResponseTypeDef:
+    ) -> ListClustersResponseTypeDef:
         """
         Returns a list of all the MSK clusters in the current Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.list_clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.list_clusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_clusters)
         """
 
     def list_configuration_revisions(
         self, *, Arn: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListConfigurationRevisionsResponseResponseTypeDef:
+    ) -> ListConfigurationRevisionsResponseTypeDef:
         """
         Returns a list of all the MSK configurations in this Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.list_configuration_revisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.list_configuration_revisions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_configuration_revisions)
         """
 
     def list_configurations(
         self, *, MaxResults: int = None, NextToken: str = None
-    ) -> ListConfigurationsResponseResponseTypeDef:
+    ) -> ListConfigurationsResponseTypeDef:
         """
         Returns a list of all the MSK configurations in this Region.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.list_configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.list_configurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_configurations)
         """
 
     def list_kafka_versions(
         self, *, MaxResults: int = None, NextToken: str = None
-    ) -> ListKafkaVersionsResponseResponseTypeDef:
+    ) -> ListKafkaVersionsResponseTypeDef:
         """
         Returns a list of Kafka versions.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.list_kafka_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.list_kafka_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_kafka_versions)
         """
 
     def list_nodes(
         self, *, ClusterArn: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListNodesResponseResponseTypeDef:
+    ) -> ListNodesResponseTypeDef:
         """
         Returns a list of the broker nodes in the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.list_nodes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.list_nodes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_nodes)
         """
 
     def list_scram_secrets(
         self, *, ClusterArn: str, MaxResults: int = None, NextToken: str = None
-    ) -> ListScramSecretsResponseResponseTypeDef:
+    ) -> ListScramSecretsResponseTypeDef:
         """
         Returns a list of the Scram Secrets associated with an Amazon MSK cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.list_scram_secrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.list_scram_secrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_scram_secrets)
         """
 
-    def list_tags_for_resource(
-        self, *, ResourceArn: str
-    ) -> ListTagsForResourceResponseResponseTypeDef:
+    def list_tags_for_resource(self, *, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
         Returns a list of the tags associated with the specified resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#list_tags_for_resource)
         """
 
     def reboot_broker(
         self, *, BrokerIds: List[str], ClusterArn: str
-    ) -> RebootBrokerResponseResponseTypeDef:
+    ) -> RebootBrokerResponseTypeDef:
         """
         Reboots brokers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.reboot_broker)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.reboot_broker)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#reboot_broker)
         """
 
@@ -354,7 +355,7 @@ class KafkaClient:
         """
         Adds tags to the specified MSK resource.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.tag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#tag_resource)
         """
 
@@ -362,17 +363,17 @@ class KafkaClient:
         """
         Removes the tags associated with the keys that are provided in the query.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.untag_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#untag_resource)
         """
 
     def update_broker_count(
         self, *, ClusterArn: str, CurrentVersion: str, TargetNumberOfBrokerNodes: int
-    ) -> UpdateBrokerCountResponseResponseTypeDef:
+    ) -> UpdateBrokerCountResponseTypeDef:
         """
         Updates the number of broker nodes in the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.update_broker_count)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.update_broker_count)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_broker_count)
         """
 
@@ -382,32 +383,32 @@ class KafkaClient:
         ClusterArn: str,
         CurrentVersion: str,
         TargetBrokerEBSVolumeInfo: List["BrokerEBSVolumeInfoTypeDef"]
-    ) -> UpdateBrokerStorageResponseResponseTypeDef:
+    ) -> UpdateBrokerStorageResponseTypeDef:
         """
         Updates the EBS storage associated with MSK brokers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.update_broker_storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.update_broker_storage)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_broker_storage)
         """
 
     def update_broker_type(
         self, *, ClusterArn: str, CurrentVersion: str, TargetInstanceType: str
-    ) -> UpdateBrokerTypeResponseResponseTypeDef:
+    ) -> UpdateBrokerTypeResponseTypeDef:
         """
         Updates EC2 instance type.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.update_broker_type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.update_broker_type)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_broker_type)
         """
 
     def update_cluster_configuration(
         self, *, ClusterArn: str, ConfigurationInfo: "ConfigurationInfoTypeDef", CurrentVersion: str
-    ) -> UpdateClusterConfigurationResponseResponseTypeDef:
+    ) -> UpdateClusterConfigurationResponseTypeDef:
         """
         Updates the cluster with the configuration that is specified in the request
         body.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.update_cluster_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.update_cluster_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_cluster_configuration)
         """
 
@@ -418,11 +419,11 @@ class KafkaClient:
         CurrentVersion: str,
         TargetKafkaVersion: str,
         ConfigurationInfo: "ConfigurationInfoTypeDef" = None
-    ) -> UpdateClusterKafkaVersionResponseResponseTypeDef:
+    ) -> UpdateClusterKafkaVersionResponseTypeDef:
         """
         Updates the Apache Kafka version for the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.update_cluster_kafka_version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.update_cluster_kafka_version)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_cluster_kafka_version)
         """
 
@@ -432,11 +433,11 @@ class KafkaClient:
         Arn: str,
         ServerProperties: Union[bytes, IO[bytes], StreamingBody],
         Description: str = None
-    ) -> UpdateConfigurationResponseResponseTypeDef:
+    ) -> UpdateConfigurationResponseTypeDef:
         """
         Updates an MSK configuration.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.update_configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.update_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_configuration)
         """
 
@@ -448,11 +449,11 @@ class KafkaClient:
         EnhancedMonitoring: EnhancedMonitoringType = None,
         OpenMonitoring: "OpenMonitoringInfoTypeDef" = None,
         LoggingInfo: "LoggingInfoTypeDef" = None
-    ) -> UpdateMonitoringResponseResponseTypeDef:
+    ) -> UpdateMonitoringResponseTypeDef:
         """
         Updates the monitoring settings for the cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Client.update_monitoring)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Client.update_monitoring)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/client.html#update_monitoring)
         """
 
@@ -461,14 +462,14 @@ class KafkaClient:
         self, operation_name: Literal["list_cluster_operations"]
     ) -> ListClusterOperationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusteroperationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_clusters"]) -> ListClustersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListClusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListClusters)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusterspaginator)
         """
 
@@ -477,7 +478,7 @@ class KafkaClient:
         self, operation_name: Literal["list_configuration_revisions"]
     ) -> ListConfigurationRevisionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationrevisionspaginator)
         """
 
@@ -486,7 +487,7 @@ class KafkaClient:
         self, operation_name: Literal["list_configurations"]
     ) -> ListConfigurationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationspaginator)
         """
 
@@ -495,14 +496,14 @@ class KafkaClient:
         self, operation_name: Literal["list_kafka_versions"]
     ) -> ListKafkaVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listkafkaversionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_nodes"]) -> ListNodesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListNodes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListNodes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listnodespaginator)
         """
 
@@ -511,6 +512,6 @@ class KafkaClient:
         self, operation_name: Literal["list_scram_secrets"]
     ) -> ListScramSecretsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listscramsecretspaginator)
         """
