@@ -35,13 +35,13 @@ from typing import Iterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import (
-    ListClusterOperationsResponseResponseTypeDef,
-    ListClustersResponseResponseTypeDef,
-    ListConfigurationRevisionsResponseResponseTypeDef,
-    ListConfigurationsResponseResponseTypeDef,
-    ListKafkaVersionsResponseResponseTypeDef,
-    ListNodesResponseResponseTypeDef,
-    ListScramSecretsResponseResponseTypeDef,
+    ListClusterOperationsResponseTypeDef,
+    ListClustersResponseTypeDef,
+    ListConfigurationRevisionsResponseTypeDef,
+    ListConfigurationsResponseTypeDef,
+    ListKafkaVersionsResponseTypeDef,
+    ListNodesResponseTypeDef,
+    ListScramSecretsResponseTypeDef,
     PaginatorConfigTypeDef,
 )
 
@@ -58,104 +58,104 @@ __all__ = (
 
 class ListClusterOperationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusteroperationspaginator)
     """
 
     def paginate(
         self, *, ClusterArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListClusterOperationsResponseResponseTypeDef]:
+    ) -> Iterator[ListClusterOperationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusteroperationspaginator)
         """
 
 
 class ListClustersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListClusters)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListClusters)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusterspaginator)
     """
 
     def paginate(
         self, *, ClusterNameFilter: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListClustersResponseResponseTypeDef]:
+    ) -> Iterator[ListClustersResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListClusters.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListClusters.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listclusterspaginator)
         """
 
 
 class ListConfigurationRevisionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationrevisionspaginator)
     """
 
     def paginate(
         self, *, Arn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListConfigurationRevisionsResponseResponseTypeDef]:
+    ) -> Iterator[ListConfigurationRevisionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationrevisionspaginator)
         """
 
 
 class ListConfigurationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListConfigurationsResponseResponseTypeDef]:
+    ) -> Iterator[ListConfigurationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListConfigurations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListConfigurations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listconfigurationspaginator)
         """
 
 
 class ListKafkaVersionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listkafkaversionspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListKafkaVersionsResponseResponseTypeDef]:
+    ) -> Iterator[ListKafkaVersionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listkafkaversionspaginator)
         """
 
 
 class ListNodesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListNodes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListNodes)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listnodespaginator)
     """
 
     def paginate(
         self, *, ClusterArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListNodesResponseResponseTypeDef]:
+    ) -> Iterator[ListNodesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListNodes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListNodes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listnodespaginator)
         """
 
 
 class ListScramSecretsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listscramsecretspaginator)
     """
 
     def paginate(
         self, *, ClusterArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListScramSecretsResponseResponseTypeDef]:
+    ) -> Iterator[ListScramSecretsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.103/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators.html#listscramsecretspaginator)
         """
